@@ -1412,7 +1412,20 @@ class WebDriver(Location, Context):
     # pylint: disable=protected-access
 
     def _addCommands(self):
-        super(WebDriver, self)._addCommands()
+        self.command_executor._commands[Command.CONTEXTS] = \
+            ('GET', '/session/$sessionId/contexts')
+        self.command_executor._commands[Command.GET_CURRENT_CONTEXT] = \
+            ('GET', '/session/$sessionId/context')
+        self.command_executor._commands[Command.SWITCH_TO_CONTEXT] = \
+            ('POST', '/session/$sessionId/context')
+
+        self.command_executor._commands[Command.TOGGLE_LOCATION_SERVICES] = \
+            ('POST', '/session/$sessionId/appium/device/toggle_location_services')
+        self.command_executor._commands[Command.GET_LOCATION] = \
+            ('GET', '/session/$sessionId/location')
+        self.command_executor._commands[Command.SET_LOCATION] = \
+            ('POST', '/session/$sessionId/location')
+
         self.command_executor._commands[Command.TOUCH_ACTION] = \
             ('POST', '/session/$sessionId/touch/perform')
         self.command_executor._commands[Command.MULTI_ACTION] = \
